@@ -55,6 +55,12 @@ class AdSel(object):
         response = self._post_resource(url, request)
         return {"response": response, "request": request}
 
+    def assign_decisions(self, decision_assignment):
+        url = "{}/assignments/decision".format(self.API)
+        request = decision_assignment.json_data()
+        response = self._post_resource(url, request)
+        return {"response": response, "request": request}
+
     def get_quarters(self, **kwargs):
         url = "{}/academicqtr".format(self.API)
         response = self._get_resource(url)
